Module state

Module state 

Shared application state for all JANUS modules

Structs

HealthStatus
Health status response
JanusState
Shared application state accessible by all modules
ModuleHealth
Module health status
ModuleHealthSummary
Module health summary for API responses

Enums

ServiceState
Service lifecycle state — controls whether processing modules are active.

Traits

AffinityRecorder
A type-erased interface for recording a realized trade outcome into the strategy-affinity tracker.
LogLevelController
A type-erased interface for changing the tracing log filter at runtime.