Shared application state for all JANUS modules
Structs
- Health
Status - Health status response
- Janus
State - Shared application state accessible by all modules
- Module
Health - Module health status
- Module
Health Summary - Module health summary for API responses
Enums
- Service
State - Service lifecycle state — controls whether processing modules are active.
Traits
- Affinity
Recorder - A type-erased interface for recording a realized trade outcome into the strategy-affinity tracker.
- LogLevel
Controller - A type-erased interface for changing the tracing log filter at runtime.